# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import instance_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/compute/v1/instance_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class InstanceServiceStub(object):
    """A set of methods for managing Instance resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Get',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/List',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Create',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Update',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Delete',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateMetadata = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/UpdateMetadata',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceMetadataRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GetSerialPortOutput = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/GetSerialPortOutput',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputResponse.FromString,
                _registered_method=True)
        self.Stop = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Stop',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Start = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Start',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Restart = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Restart',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RestartInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.AttachDisk = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/AttachDisk',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.DetachDisk = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/DetachDisk',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.AttachFilesystem = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/AttachFilesystem',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceFilesystemRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.DetachFilesystem = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/DetachFilesystem',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceFilesystemRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.AttachNetworkInterface = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/AttachNetworkInterface',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceNetworkInterfaceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.DetachNetworkInterface = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/DetachNetworkInterface',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceNetworkInterfaceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.AddOneToOneNat = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/AddOneToOneNat',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AddInstanceOneToOneNatRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.RemoveOneToOneNat = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/RemoveOneToOneNat',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RemoveInstanceOneToOneNatRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateNetworkInterface = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/UpdateNetworkInterface',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceNetworkInterfaceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsResponse.FromString,
                _registered_method=True)
        self.Move = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Move',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.MoveInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Relocate = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Relocate',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RelocateInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.SimulateMaintenanceEvent = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/SimulateMaintenanceEvent',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.SimulateInstanceMaintenanceEventRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                _registered_method=True)
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class InstanceServiceServicer(object):
    """A set of methods for managing Instance resources.
    """

    def Get(self, request, context):
        """Returns the specified Instance resource.

        To get the list of available Instance resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Instance resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates an instance in the specified folder.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMetadata(self, request, context):
        """Updates the metadata of the specified instance. For more information on metadata, see [VM metadata](/docs/compute/concepts/vm-metadata).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSerialPortOutput(self, request, context):
        """Returns the serial port output of the specified Instance resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Stops the running instance.

        You can start the instance later using the [InstanceService.Start] method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Starts the stopped instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Restart(self, request, context):
        """Restarts the running instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachDisk(self, request, context):
        """Attaches the disk to the instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachDisk(self, request, context):
        """Detaches the disk from the instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachFilesystem(self, request, context):
        """Attaches the filesystem to the instance.

        The instance and the filesystem must reside in the same availability zone.

        To use the instance with an attached filesystem, the latter must be mounted.
        For details, see [documentation](/docs/compute/operations/filesystem/attach-to-vm).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachFilesystem(self, request, context):
        """Detaches the filesystem from the instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachNetworkInterface(self, request, context):
        """Attaches the network-interface to the instance.

        To attach a network-interface, the instance must have a `STOPPED` status ([Instance.status]).
        To check the instance status, make a [InstanceService.Get] request.
        To stop the running instance, make a [InstanceService.Stop] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachNetworkInterface(self, request, context):
        """Detaches the network-interface to the instance.

        To Detach a network-interface, the instance must have a `STOPPED` status ([Instance.status]).
        To check the instance status, make a [InstanceService.Get] request.
        To stop the running instance, make a [InstanceService.Stop] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddOneToOneNat(self, request, context):
        """Enables One-to-one NAT on the network interface.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveOneToOneNat(self, request, context):
        """Removes One-to-one NAT from the network interface.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNetworkInterface(self, request, context):
        """Updates the specified instance network interface.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Move(self, request, context):
        """Moves the specified instance to another folder of the same cloud.

        The instance must be stopped before moving. To stop the instance, make a [Stop] request.

        After moving, the instance will start recording its Monitoring default metrics to its new folder. Metrics
        that have been recorded to the source folder prior to moving will be retained.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Relocate(self, request, context):
        """Moves the specified instance to another availability zone

        Running instance will be restarted during this operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimulateMaintenanceEvent(self, request, context):
        """maintenance

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """access

        Lists access bindings for the instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InstanceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.Instance.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMetadata,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceMetadataRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetSerialPortOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSerialPortOutput,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputResponse.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Restart': grpc.unary_unary_rpc_method_handler(
                    servicer.Restart,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RestartInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AttachDisk': grpc.unary_unary_rpc_method_handler(
                    servicer.AttachDisk,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DetachDisk': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachDisk,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AttachFilesystem': grpc.unary_unary_rpc_method_handler(
                    servicer.AttachFilesystem,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceFilesystemRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DetachFilesystem': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachFilesystem,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceFilesystemRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AttachNetworkInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.AttachNetworkInterface,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceNetworkInterfaceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DetachNetworkInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachNetworkInterface,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceNetworkInterfaceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddOneToOneNat': grpc.unary_unary_rpc_method_handler(
                    servicer.AddOneToOneNat,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AddInstanceOneToOneNatRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveOneToOneNat': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveOneToOneNat,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RemoveInstanceOneToOneNatRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateNetworkInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNetworkInterface,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceNetworkInterfaceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsResponse.SerializeToString,
            ),
            'Move': grpc.unary_unary_rpc_method_handler(
                    servicer.Move,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.MoveInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Relocate': grpc.unary_unary_rpc_method_handler(
                    servicer.Relocate,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RelocateInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SimulateMaintenanceEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.SimulateMaintenanceEvent,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.SimulateInstanceMaintenanceEventRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.compute.v1.InstanceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.compute.v1.InstanceService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InstanceService(object):
    """A set of methods for managing Instance resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Get',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/List',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Create',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Update',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Delete',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/UpdateMetadata',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceMetadataRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSerialPortOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/GetSerialPortOutput',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Stop',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Start',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Restart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Restart',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RestartInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AttachDisk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/AttachDisk',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DetachDisk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/DetachDisk',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AttachFilesystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/AttachFilesystem',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceFilesystemRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DetachFilesystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/DetachFilesystem',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceFilesystemRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AttachNetworkInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/AttachNetworkInterface',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceNetworkInterfaceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DetachNetworkInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/DetachNetworkInterface',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceNetworkInterfaceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddOneToOneNat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/AddOneToOneNat',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AddInstanceOneToOneNatRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveOneToOneNat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/RemoveOneToOneNat',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RemoveInstanceOneToOneNatRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateNetworkInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/UpdateNetworkInterface',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceNetworkInterfaceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/ListOperations',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Move(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Move',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.MoveInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Relocate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/Relocate',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RelocateInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SimulateMaintenanceEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/SimulateMaintenanceEvent',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.SimulateInstanceMaintenanceEventRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.compute.v1.InstanceService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Operation(google.protobuf.message.Message):
    """Operation is annotation for rpc that returns longrunning operation, describes
    message types that will be returned in metadata [google.protobuf.Any], and
    in response [google.protobuf.Any] (for successful operation).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    metadata: builtins.str
    """Optional. If present, rpc returns operation which metadata field will
    contains message of specified type.
    Optional.
    """
    response: builtins.str
    """Required. rpc returns operation, in case of success response will contains message of
    specified field.
    Required.
    """
    def __init__(
        self,
        *,
        metadata: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["metadata", b"metadata", "response", b"response"]) -> None: ...

global___Operation = Operation

OPERATION_FIELD_NUMBER: builtins.int
operation: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MethodOptions, global___Operation]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing
import yandex.cloud.datasphere.v1.project_pb2
import yandex.cloud.datasphere.v1.project_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ProjectServiceStub:
    """A set of methods for managing Project resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.CreateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a project in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.UpdateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified project."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.DeleteProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified project."""

    Open: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.OpenProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens the specified project."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.GetProjectRequest,
        yandex.cloud.datasphere.v1.project_pb2.Project,
    ]
    """Returns the specified project."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsRequest,
        yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsResponse,
    ]
    """Lists projects for the specified folder."""

    GetUnitBalance: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceRequest,
        yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceResponse,
    ]
    """Returns the unit balance of the specified project."""

    SetUnitBalance: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.SetUnitBalanceRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Sets the unit balance of the specified project."""

    Execute: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.ProjectExecutionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Executes code in the specified cell or notebook."""

class ProjectServiceAsyncStub:
    """A set of methods for managing Project resources."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.CreateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a project in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.UpdateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified project."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.DeleteProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified project."""

    Open: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.OpenProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens the specified project."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.GetProjectRequest,
        yandex.cloud.datasphere.v1.project_pb2.Project,
    ]
    """Returns the specified project."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsRequest,
        yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsResponse,
    ]
    """Lists projects for the specified folder."""

    GetUnitBalance: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceRequest,
        yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceResponse,
    ]
    """Returns the unit balance of the specified project."""

    SetUnitBalance: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.SetUnitBalanceRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Sets the unit balance of the specified project."""

    Execute: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.ProjectExecutionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Executes code in the specified cell or notebook."""

class ProjectServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Project resources."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.CreateProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a project in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.UpdateProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified project."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.DeleteProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified project."""

    @abc.abstractmethod
    def Open(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.OpenProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Opens the specified project."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.GetProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.project_pb2.Project, collections.abc.Awaitable[yandex.cloud.datasphere.v1.project_pb2.Project]]:
        """Returns the specified project."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsResponse]]:
        """Lists projects for the specified folder."""

    @abc.abstractmethod
    def GetUnitBalance(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceResponse]]:
        """Returns the unit balance of the specified project."""

    @abc.abstractmethod
    def SetUnitBalance(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.SetUnitBalanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Sets the unit balance of the specified project."""

    @abc.abstractmethod
    def Execute(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.ProjectExecutionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Executes code in the specified cell or notebook."""

def add_ProjectServiceServicer_to_server(servicer: ProjectServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dataproc/v1/subcluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dataproc/v1/subcluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.dataproc.v1 import common_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/dataproc/v1/subcluster.proto\x12\x18yandex.cloud.dataproc.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%yandex/cloud/dataproc/v1/common.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/duration.proto\"\xf1\x02\n\x11\x41utoscalingConfig\x12\"\n\x0fmax_hosts_count\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100\x12\x13\n\x0bpreemptible\x18\x02 \x01(\x08\x12G\n\x14measurement_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xe8\xc7\x31\x01\xfa\xc7\x31\x06\x31m-10m\x12=\n\x0fwarmup_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=10m\x12\x45\n\x16stabilization_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31m-30m\x12)\n\x16\x63pu_utilization_target\x18\x06 \x01(\x01\x42\t\xfa\xc7\x31\x05\x30-100\x12)\n\x14\x64\x65\x63ommission_timeout\x18\x07 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\"\x80\x03\n\nSubcluster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x04name\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04\x31-63\x12,\n\x04role\x18\x05 \x01(\x0e\x32\x1e.yandex.cloud.dataproc.v1.Role\x12\x36\n\tresources\x18\x06 \x01(\x0b\x32#.yandex.cloud.dataproc.v1.Resources\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x13\n\x0bhosts_count\x18\x08 \x01(\x03\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\x12G\n\x12\x61utoscaling_config\x18\n \x01(\x0b\x32+.yandex.cloud.dataproc.v1.AutoscalingConfig\x12\x19\n\x11instance_group_id\x18\x0b \x01(\t\"\xa8\x01\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rsubcluster_id\x18\x02 \x01(\t\x12\x30\n\x06health\x18\x03 \x01(\x0e\x32 .yandex.cloud.dataproc.v1.Health\x12\x1b\n\x13\x63ompute_instance_id\x18\x04 \x01(\t\x12,\n\x04role\x18\x05 \x01(\x0e\x32\x1e.yandex.cloud.dataproc.v1.Role*K\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0e\n\nMASTERNODE\x10\x01\x12\x0c\n\x08\x44\x41TANODE\x10\x02\x12\x0f\n\x0b\x43OMPUTENODE\x10\x03\x42\x65\n\x1cyandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.v1.subcluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc'
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['max_hosts_count']._loaded_options = None
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['max_hosts_count']._serialized_options = b'\372\3071\0051-100'
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['measurement_duration']._loaded_options = None
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['measurement_duration']._serialized_options = b'\350\3071\001\372\3071\0061m-10m'
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['warmup_duration']._loaded_options = None
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['warmup_duration']._serialized_options = b'\372\3071\005<=10m'
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['stabilization_duration']._loaded_options = None
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['stabilization_duration']._serialized_options = b'\372\3071\0061m-30m'
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['cpu_utilization_target']._loaded_options = None
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['cpu_utilization_target']._serialized_options = b'\372\3071\0050-100'
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['decommission_timeout']._loaded_options = None
  _globals['_AUTOSCALINGCONFIG'].fields_by_name['decommission_timeout']._serialized_options = b'\372\3071\0070-86400'
  _globals['_SUBCLUSTER'].fields_by_name['name']._loaded_options = None
  _globals['_SUBCLUSTER'].fields_by_name['name']._serialized_options = b'\212\3101\0041-63'
  _globals['_ROLE']._serialized_start=1136
  _globals['_ROLE']._serialized_end=1211
  _globals['_AUTOSCALINGCONFIG']._serialized_start=207
  _globals['_AUTOSCALINGCONFIG']._serialized_end=576
  _globals['_SUBCLUSTER']._serialized_start=579
  _globals['_SUBCLUSTER']._serialized_end=963
  _globals['_HOST']._serialized_start=966
  _globals['_HOST']._serialized_end=1134
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        STOPPING: Cluster._Status.ValueType  # 4
        """Cluster is being stopped."""
        STOPPED: Cluster._Status.ValueType  # 5
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 6
        """Cluster is being started."""
        UPDATING: Cluster._Status.ValueType  # 7
        """Cluster is being updated."""
        DELETING: Cluster._Status.ValueType  # 8
        """Cluster is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    STOPPING: Cluster.Status.ValueType  # 4
    """Cluster is being stopped."""
    STOPPED: Cluster.Status.ValueType  # 5
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 6
    """Cluster is being started."""
    UPDATING: Cluster.Status.ValueType  # 7
    """Cluster is being updated."""
    DELETING: Cluster.Status.ValueType  # 8
    """Cluster is being deleted."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is dead."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is degraded."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is dead."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is degraded."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class Endpoints(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UI_FIELD_NUMBER: builtins.int
        EXTERNAL_HTTP_PROXY_BALANCER_FIELD_NUMBER: builtins.int
        INTERNAL_HTTP_PROXY_ALIAS_FIELD_NUMBER: builtins.int
        INTERNAL_RPC_PROXY_ALIAS_FIELD_NUMBER: builtins.int
        ui: builtins.str
        """https://CID.ui.ytsaurus.yandexcloud.net"""
        external_http_proxy_balancer: builtins.str
        """https://CID.proxy.ytsaurus.yandexcloud.net"""
        internal_http_proxy_alias: builtins.str
        """https://hp.CID.ytsaurus.mdb.yandexcloud.net:PORT"""
        internal_rpc_proxy_alias: builtins.str
        """rp.CID.ytsaurus.mdb.yandexcloud.net:PORT"""
        def __init__(
            self,
            *,
            ui: builtins.str = ...,
            external_http_proxy_balancer: builtins.str = ...,
            internal_http_proxy_alias: builtins.str = ...,
            internal_rpc_proxy_alias: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["external_http_proxy_balancer", b"external_http_proxy_balancer", "internal_http_proxy_alias", b"internal_http_proxy_alias", "internal_rpc_proxy_alias", b"internal_rpc_proxy_alias", "ui", b"ui"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_BY_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the cluster. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the cluster belongs to."""
    zone_id: builtins.str
    """ID of the availability zone where the cluster resides."""
    name: builtins.str
    """Name of the cluster.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the cluster."""
    subnet_id: builtins.str
    """ID of the subnet where the cluster resides."""
    created_by: builtins.str
    """User who created the cluster."""
    updated_by: builtins.str
    """User who last updated the cluster."""
    status: global___Cluster.Status.ValueType
    """Status of the cluster."""
    health: global___Cluster.Health.ValueType
    """Health of the cluster."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Cluster labels as `key:value` pairs."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Network interfaces security groups."""

    @property
    def spec(self) -> global___ClusterSpec:
        """Cluster specification."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the cluster was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the cluster was last updated."""

    @property
    def endpoints(self) -> global___Cluster.Endpoints:
        """Endpoints of the cluster."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        spec: global___ClusterSpec | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_by: builtins.str = ...,
        status: global___Cluster.Status.ValueType = ...,
        health: global___Cluster.Health.ValueType = ...,
        endpoints: global___Cluster.Endpoints | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "endpoints", b"endpoints", "spec", b"spec", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by", b"created_by", "description", b"description", "endpoints", b"endpoints", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "name", b"name", "security_group_ids", b"security_group_ids", "spec", b"spec", "status", b"status", "subnet_id", b"subnet_id", "updated_at", b"updated_at", "updated_by", b"updated_by", "zone_id", b"zone_id"]) -> None: ...

global___Cluster = Cluster

@typing.final
class StorageSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HddSpec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_GB_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        size_gb: builtins.int
        count: builtins.int
        def __init__(
            self,
            *,
            size_gb: builtins.int = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "size_gb", b"size_gb"]) -> None: ...

    @typing.final
    class SsdSpec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_GB_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        size_gb: builtins.int
        type: builtins.str
        count: builtins.int
        def __init__(
            self,
            *,
            size_gb: builtins.int = ...,
            type: builtins.str = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "size_gb", b"size_gb", "type", b"type"]) -> None: ...

    HDD_FIELD_NUMBER: builtins.int
    SSD_FIELD_NUMBER: builtins.int
    @property
    def hdd(self) -> global___StorageSpec.HddSpec: ...
    @property
    def ssd(self) -> global___StorageSpec.SsdSpec: ...
    def __init__(
        self,
        *,
        hdd: global___StorageSpec.HddSpec | None = ...,
        ssd: global___StorageSpec.SsdSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hdd", b"hdd", "ssd", b"ssd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hdd", b"hdd", "ssd", b"ssd"]) -> None: ...

global___StorageSpec = StorageSpec

@typing.final
class ComputeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DiskSpec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TYPE_FIELD_NUMBER: builtins.int
        SIZE_GB_FIELD_NUMBER: builtins.int
        LOCATIONS_FIELD_NUMBER: builtins.int
        type: builtins.str
        size_gb: builtins.int
        @property
        def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            type: builtins.str = ...,
            size_gb: builtins.int = ...,
            locations: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["locations", b"locations", "size_gb", b"size_gb", "type", b"type"]) -> None: ...

    @typing.final
    class ScalePolicy(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class FixedScale(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            SIZE_FIELD_NUMBER: builtins.int
            size: builtins.int
            def __init__(
                self,
                *,
                size: builtins.int = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["size", b"size"]) -> None: ...

        @typing.final
        class AutoScale(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            MIN_SIZE_FIELD_NUMBER: builtins.int
            MAX_SIZE_FIELD_NUMBER: builtins.int
            min_size: builtins.int
            max_size: builtins.int
            def __init__(
                self,
                *,
                min_size: builtins.int = ...,
                max_size: builtins.int = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["max_size", b"max_size", "min_size", b"min_size"]) -> None: ...

        FIXED_FIELD_NUMBER: builtins.int
        AUTO_FIELD_NUMBER: builtins.int
        @property
        def fixed(self) -> global___ComputeSpec.ScalePolicy.FixedScale: ...
        @property
        def auto(self) -> global___ComputeSpec.ScalePolicy.AutoScale: ...
        def __init__(
            self,
            *,
            fixed: global___ComputeSpec.ScalePolicy.FixedScale | None = ...,
            auto: global___ComputeSpec.ScalePolicy.AutoScale | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["auto", b"auto", "fixed", b"fixed", "policy", b"policy"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["auto", b"auto", "fixed", b"fixed", "policy", b"policy"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["policy", b"policy"]) -> typing.Literal["fixed", "auto"] | None: ...

    PRESET_FIELD_NUMBER: builtins.int
    DISKS_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    preset: builtins.str
    name: builtins.str
    """Name for exec pool."""
    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeSpec.DiskSpec]: ...
    @property
    def scale_policy(self) -> global___ComputeSpec.ScalePolicy: ...
    def __init__(
        self,
        *,
        preset: builtins.str = ...,
        disks: collections.abc.Iterable[global___ComputeSpec.DiskSpec] | None = ...,
        scale_policy: global___ComputeSpec.ScalePolicy | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scale_policy", b"scale_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disks", b"disks", "name", b"name", "preset", b"preset", "scale_policy", b"scale_policy"]) -> None: ...

global___ComputeSpec = ComputeSpec

@typing.final
class HttpProxySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count"]) -> None: ...

global___HttpProxySpec = HttpProxySpec

@typing.final
class RpcProxySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count"]) -> None: ...

global___RpcProxySpec = RpcProxySpec

@typing.final
class TabletSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRESET_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    preset: builtins.str
    count: builtins.int
    def __init__(
        self,
        *,
        preset: builtins.str = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count", "preset", b"preset"]) -> None: ...

global___TabletSpec = TabletSpec

@typing.final
class ProxySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_FIELD_NUMBER: builtins.int
    RPC_FIELD_NUMBER: builtins.int
    @property
    def http(self) -> global___HttpProxySpec: ...
    @property
    def rpc(self) -> global___RpcProxySpec: ...
    def __init__(
        self,
        *,
        http: global___HttpProxySpec | None = ...,
        rpc: global___RpcProxySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["http", b"http", "rpc", b"rpc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["http", b"http", "rpc", b"rpc"]) -> None: ...

global___ProxySpec = ProxySpec

@typing.final
class OdinSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECKS_TTL_FIELD_NUMBER: builtins.int
    @property
    def checks_ttl(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        checks_ttl: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["checks_ttl", b"checks_ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["checks_ttl", b"checks_ttl"]) -> None: ...

global___OdinSpec = OdinSpec

@typing.final
class ClusterSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_FIELD_NUMBER: builtins.int
    COMPUTE_FIELD_NUMBER: builtins.int
    TABLET_FIELD_NUMBER: builtins.int
    PROXY_FIELD_NUMBER: builtins.int
    ODIN_FIELD_NUMBER: builtins.int
    @property
    def storage(self) -> global___StorageSpec: ...
    @property
    def compute(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeSpec]: ...
    @property
    def tablet(self) -> global___TabletSpec: ...
    @property
    def proxy(self) -> global___ProxySpec: ...
    @property
    def odin(self) -> global___OdinSpec: ...
    def __init__(
        self,
        *,
        storage: global___StorageSpec | None = ...,
        compute: collections.abc.Iterable[global___ComputeSpec] | None = ...,
        tablet: global___TabletSpec | None = ...,
        proxy: global___ProxySpec | None = ...,
        odin: global___OdinSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["odin", b"odin", "proxy", b"proxy", "storage", b"storage", "tablet", b"tablet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compute", b"compute", "odin", b"odin", "proxy", b"proxy", "storage", b"storage", "tablet", b"tablet"]) -> None: ...

global___ClusterSpec = ClusterSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PutEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to put event."""
    body: builtins.str
    """Event body."""
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        body: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "bus_id", b"bus_id"]) -> None: ...

global___PutEventRequest = PutEventRequest

@typing.final
class SendEventsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector to send events."""
    @property
    def message(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Batch of events bodies."""

    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
        message: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id", "message", b"message"]) -> None: ...

global___SendEventsRequest = SendEventsRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class EnsureLockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_TOKEN_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    instance_token: builtins.str
    """Signed JWT token which contains information about subscription."""
    resource_id: builtins.str
    """ID of the resource to which the subscription will be locked."""
    def __init__(
        self,
        *,
        instance_token: builtins.str = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_token", b"instance_token", "resource_id", b"resource_id"]) -> None: ...

global___EnsureLockRequest = EnsureLockRequest

@typing.final
class EnsureLockMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_ID_FIELD_NUMBER: builtins.int
    lock_id: builtins.str
    """ID of the subscription lock."""
    def __init__(
        self,
        *,
        lock_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lock_id", b"lock_id"]) -> None: ...

global___EnsureLockMetadata = EnsureLockMetadata

@typing.final
class GetLockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_ID_FIELD_NUMBER: builtins.int
    lock_id: builtins.str
    """ID of the subscription lock."""
    def __init__(
        self,
        *,
        lock_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lock_id", b"lock_id"]) -> None: ...

global___GetLockRequest = GetLockRequest

@typing.final
class GetLockByResourceIDRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource to with subscription is locked."""
    instance_id: builtins.str
    """ID of the subscription"""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id", "resource_id", b"resource_id"]) -> None: ...

global___GetLockByResourceIDRequest = GetLockByResourceIDRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/vision/v2/image_classifier.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/vision/v2/image_classifier.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.vision.v2 import image_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/ai/vision/v2/image_classifier.proto\x12\x19yandex.cloud.ai.vision.v2\x1a%yandex/cloud/ai/vision/v2/image.proto\"*\n\x05Label\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"V\n\x0f\x43lassAnnotation\x12/\n\x05label\x18\x01 \x01(\x0b\x32 .yandex.cloud.ai.vision.v2.Label\x12\x12\n\nconfidence\x18\x02 \x01(\x01\"\x8c\x02\n\x17\x43lassifierSpecification\x12\x30\n\x06labels\x18\x01 \x03(\x0b\x32 .yandex.cloud.ai.vision.v2.Label\x12\x62\n\x13\x63lassification_type\x18\x02 \x01(\x0e\x32\x45.yandex.cloud.ai.vision.v2.ClassifierSpecification.ClassificationType\"[\n\x12\x43lassificationType\x12#\n\x1f\x43LASSIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bMULTI_LABEL\x10\x01\x12\x0f\n\x0bMULTI_CLASS\x10\x02\"\xbf\x01\n\x12\x41nnotationResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12T\n\x18\x63lassifier_specification\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.ai.vision.v2.ClassifierSpecification\x12?\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32*.yandex.cloud.ai.vision.v2.ClassAnnotation\"D\n\x11\x41nnotationRequest\x12/\n\x05image\x18\x01 \x01(\x0b\x32 .yandex.cloud.ai.vision.v2.ImageBe\n\x1dyandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;visionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.vision.v2.image_classifier_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;vision'
  _globals['_LABEL']._serialized_start=118
  _globals['_LABEL']._serialized_end=160
  _globals['_CLASSANNOTATION']._serialized_start=162
  _globals['_CLASSANNOTATION']._serialized_end=248
  _globals['_CLASSIFIERSPECIFICATION']._serialized_start=251
  _globals['_CLASSIFIERSPECIFICATION']._serialized_end=519
  _globals['_CLASSIFIERSPECIFICATION_CLASSIFICATIONTYPE']._serialized_start=428
  _globals['_CLASSIFIERSPECIFICATION_CLASSIFICATIONTYPE']._serialized_end=519
  _globals['_ANNOTATIONRESPONSE']._serialized_start=522
  _globals['_ANNOTATIONRESPONSE']._serialized_end=713
  _globals['_ANNOTATIONREQUEST']._serialized_start=715
  _globals['_ANNOTATIONREQUEST']._serialized_end=783
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/points.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/points.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/speechsense/v1/analysis/points.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a\x1egoogle/protobuf/wrappers.proto\"B\n\x06Points\x12\x38\n\x04quiz\x18\x01 \x03(\x0b\x32*.yandex.cloud.speechsense.v1.analysis.Quiz\"S\n\x04Quiz\x12\x0f\n\x07request\x18\x01 \x01(\t\x12.\n\x08response\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\n\n\x02id\x18\x03 \x01(\tB\x8d\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x0bPointsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.points_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\013PointsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_POINTS']._serialized_start=123
  _globals['_POINTS']._serialized_end=189
  _globals['_QUIZ']._serialized_start=191
  _globals['_QUIZ']._serialized_end=274
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetWafProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WAF_PROFILE_ID_FIELD_NUMBER: builtins.int
    waf_profile_id: builtins.str
    """ID of the WafProfile resource to return."""
    def __init__(
        self,
        *,
        waf_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["waf_profile_id", b"waf_profile_id"]) -> None: ...

global___GetWafProfileRequest = GetWafProfileRequest

@typing.final
class ListWafProfilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the WAF profile belongs to.
    Currently page_size, page_token, filter and order_by are not supported and List method will return all WAF profiles in the folder.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListWafProfilesRequest = ListWafProfilesRequest

@typing.final
class ListWafProfilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WAF_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def waf_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile]:
        """List of WafProfile resources.
        Currently next_page_token is not supported and List method will return all WAF profiles in the folder.
        """

    def __init__(
        self,
        *,
        waf_profiles: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["waf_profiles", b"waf_profiles"]) -> None: ...

global___ListWafProfilesResponse = ListWafProfilesResponse

@typing.final
class CreateWafProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    EXCLUSION_RULES_FIELD_NUMBER: builtins.int
    CORE_RULE_SET_FIELD_NUMBER: builtins.int
    ANALYZE_REQUEST_BODY_FIELD_NUMBER: builtins.int
    RULE_SETS_FIELD_NUMBER: builtins.int
    MATCH_ALL_RULE_SETS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a WAF profile in."""
    name: builtins.str
    """Name of the WAF profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the WAF profile."""
    match_all_rule_sets: builtins.bool
    """Parameter determines should all rule sets be matched."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfileRule]:
        """Settings for each rule in rule set."""

    @property
    def exclusion_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfileExclusionRule]:
        """List of exclusion rules. See [Rules](/docs/smartwebsecurity/concepts/waf#exclusion-rules)."""

    @property
    def core_rule_set(self) -> yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.CoreRuleSet:
        """Core rule set settings. See [Basic rule set](/docs/smartwebsecurity/concepts/waf#rules-set) for details."""

    @property
    def analyze_request_body(self) -> yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.AnalyzeRequestBody:
        """Parameters for request body analyzer."""

    @property
    def rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.WafProfileRuleSet]:
        """List of rule sets. See [Rules](/docs/smartwebsecurity/concepts/waf#rules-set)."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfileRule] | None = ...,
        exclusion_rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfileExclusionRule] | None = ...,
        core_rule_set: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.CoreRuleSet | None = ...,
        analyze_request_body: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.AnalyzeRequestBody | None = ...,
        rule_sets: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.WafProfileRuleSet] | None = ...,
        match_all_rule_sets: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_request_body", b"analyze_request_body", "core_rule_set", b"core_rule_set", "rule_set", b"rule_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_request_body", b"analyze_request_body", "core_rule_set", b"core_rule_set", "description", b"description", "exclusion_rules", b"exclusion_rules", "folder_id", b"folder_id", "labels", b"labels", "match_all_rule_sets", b"match_all_rule_sets", "name", b"name", "rule_set", b"rule_set", "rule_sets", b"rule_sets", "rules", b"rules"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["rule_set", b"rule_set"]) -> typing.Literal["core_rule_set"] | None: ...

global___CreateWafProfileRequest = CreateWafProfileRequest

@typing.final
class CreateWafProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WAF_PROFILE_ID_FIELD_NUMBER: builtins.int
    waf_profile_id: builtins.str
    """ID of the WAF profile that is being created."""
    def __init__(
        self,
        *,
        waf_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["waf_profile_id", b"waf_profile_id"]) -> None: ...

global___CreateWafProfileMetadata = CreateWafProfileMetadata

@typing.final
class UpdateWafProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    WAF_PROFILE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    EXCLUSION_RULES_FIELD_NUMBER: builtins.int
    CORE_RULE_SET_FIELD_NUMBER: builtins.int
    ANALYZE_REQUEST_BODY_FIELD_NUMBER: builtins.int
    RULE_SETS_FIELD_NUMBER: builtins.int
    MATCH_ALL_RULE_SETS_FIELD_NUMBER: builtins.int
    waf_profile_id: builtins.str
    """ID of the WAF profile to update."""
    name: builtins.str
    """Name of the WAF profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the WAF profile."""
    match_all_rule_sets: builtins.bool
    """Parameter determines should all rule sets be matched."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the WafProfile resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfileRule]:
        """Settings for each rule in rule set."""

    @property
    def exclusion_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfileExclusionRule]:
        """List of exclusion rules. See [Rules](/docs/smartwebsecurity/concepts/waf#exclusion-rules)."""

    @property
    def core_rule_set(self) -> yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.CoreRuleSet:
        """Core rule set settings. See [Basic rule set](/docs/smartwebsecurity/concepts/waf#rules-set) for details."""

    @property
    def analyze_request_body(self) -> yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.AnalyzeRequestBody:
        """Parameters for request body analyzer."""

    @property
    def rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.WafProfileRuleSet]:
        """List of rule sets. See [Rules](/docs/smartwebsecurity/concepts/waf#rules-set)."""

    def __init__(
        self,
        *,
        waf_profile_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfileRule] | None = ...,
        exclusion_rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfileExclusionRule] | None = ...,
        core_rule_set: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.CoreRuleSet | None = ...,
        analyze_request_body: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.AnalyzeRequestBody | None = ...,
        rule_sets: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile.WafProfileRuleSet] | None = ...,
        match_all_rule_sets: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_request_body", b"analyze_request_body", "core_rule_set", b"core_rule_set", "rule_set", b"rule_set", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_request_body", b"analyze_request_body", "core_rule_set", b"core_rule_set", "description", b"description", "exclusion_rules", b"exclusion_rules", "labels", b"labels", "match_all_rule_sets", b"match_all_rule_sets", "name", b"name", "rule_set", b"rule_set", "rule_sets", b"rule_sets", "rules", b"rules", "update_mask", b"update_mask", "waf_profile_id", b"waf_profile_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["rule_set", b"rule_set"]) -> typing.Literal["core_rule_set"] | None: ...

global___UpdateWafProfileRequest = UpdateWafProfileRequest

@typing.final
class UpdateWafProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WAF_PROFILE_ID_FIELD_NUMBER: builtins.int
    waf_profile_id: builtins.str
    """ID of the WafProfile resource that is being updated."""
    def __init__(
        self,
        *,
        waf_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["waf_profile_id", b"waf_profile_id"]) -> None: ...

global___UpdateWafProfileMetadata = UpdateWafProfileMetadata

@typing.final
class DeleteWafProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WAF_PROFILE_ID_FIELD_NUMBER: builtins.int
    waf_profile_id: builtins.str
    """ID of the WAF profile to delete."""
    def __init__(
        self,
        *,
        waf_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["waf_profile_id", b"waf_profile_id"]) -> None: ...

global___DeleteWafProfileRequest = DeleteWafProfileRequest

@typing.final
class DeleteWafProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WAF_PROFILE_ID_FIELD_NUMBER: builtins.int
    waf_profile_id: builtins.str
    """ID of the WafProfile resource that is being deleted."""
    def __init__(
        self,
        *,
        waf_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["waf_profile_id", b"waf_profile_id"]) -> None: ...

global___DeleteWafProfileMetadata = DeleteWafProfileMetadata
